:orphan:

`plasmapy.formulary.collisions.coulomb`
=======================================

.. currentmodule:: plasmapy.formulary.collisions.coulomb

.. automodapi:: plasmapy.formulary.collisions.coulomb
